==> cohesity_management_sdk-1.9.1.tar.gz: cohesity_management_sdk-1.9.1/cohesity_management_sdk/models/ews_to_pst_conversion_params.py <==
# -*- coding: utf-8 -*-
# Copyright 2023 Cohesity Inc.

class EwsToPstConversionParams(object):

    """Implementation of the 'EwsToPstConversionParams' model.

    TODO: type description here.


    Attributes:

        create_pst (bool): Create Msg files or Pst. false value indicates only
            create msg files. Default value is true.
        option_flags (int): ConvertEwsToPst flags of type
            ConvertEwsToPSTOptionFlags.
        pst_name_prefix (string): Name prefix for generated PST files.
        pst_password (string): Optional password to be set for the output PSTs.
        pst_size_threshold (long|int): PST rotation size in bytes.
    """


    # Create a mapping from Model property names to API property names
    _names = {
        "create_pst":'createPst',
        "option_flags":'optionFlags',
        "pst_name_prefix":'pstNamePrefix',
        "pst_password":'pstPassword',
        "pst_size_threshold":'pstSizeThreshold',
    }
    def __init__(self,
                 create_pst=None,
                 option_flags=None,
                 pst_name_prefix=None,
                 pst_password=None,
                 pst_size_threshold=None,
            ):

        """Constructor for the EwsToPstConversionParams class"""

        # Initialize members of the class
        self.create_pst = create_pst
        self.option_flags = option_flags
        self.pst_name_prefix = pst_name_prefix
        self.pst_password = pst_password
        self.pst_size_threshold = pst_size_threshold

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        create_pst = dictionary.get('createPst')
        option_flags = dictionary.get('optionFlags')
        pst_name_prefix = dictionary.get('pstNamePrefix')
        pst_password = dictionary.get('pstPassword')
        pst_size_threshold = dictionary.get('pstSizeThreshold')

        # Return an object of this model
        return cls(
            create_pst,
            option_flags,
            pst_name_prefix,
            pst_password,
            pst_size_threshold
)

==> cohesity_management_sdk-1.11.2.tar.gz: cohesity_management_sdk-1.11.2/cohesity_management_sdk/models/ews_to_pst_conversion_params.py <==
# -*- coding: utf-8 -*-
# Copyright 2024 Cohesity Inc.


class EwsToPstConversionParams(object):

    """Implementation of the 'EwsToPstConversionParams' model.

    Attributes:
        create_pst (bool): Create Msg files or Pst.
            false value indicates only create msg files.
            Default value is true.
        encrypted_pst_password (string): Encrypted version of the pst_password
            above. The plain password should be cleared and the encrypted form
            should be persisted in the restore task
            state proto.
        option_flags (int): ConvertEwsToPst flags of pstSizeThreshold
            ConvertEwsToPSTOptionFlags.
        pst_name_prefix (string): Name prefix for generated PST files.
        pst_password (string): Optional password to be set for the output PSTs.
        pst_size_threshold (long|int): PST rotation size in bytes.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "create_pst":'createPst',
        "encrypted_pst_password": 'encryptedPstPassword',
        "option_flags":'optionFlags',
        "pst_name_prefix":'pstNamePrefix',
        "pst_password":'pstPassword',
        "pst_size_threshold":'pstSizeThreshold'
    }

    def __init__(self,
                 create_pst=None,
                 encrypted_pst_password=None,
                 option_flags=None,
                 pst_name_prefix=None,
                 pst_password=None,
                 pst_size_threshold=None):
        """Constructor for the EwsToPstConversionParams class"""

        # Initialize members of the class
        self.create_pst = create_pst
        self.encrypted_pst_password = encrypted_pst_password
        self.option_flags = option_flags
        self.pst_name_prefix = pst_name_prefix
        self.pst_password = pst_password
        self.pst_size_threshold = pst_size_threshold


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        create_pst = dictionary.get('createPst')
        encrypted_pst_password = dictionary.get('encryptedPstPassword')
        option_flags = dictionary.get('optionFlags')
        pst_name_prefix = dictionary.get('pstNamePrefix')
        pst_size_threshold = dictionary.get('pstSizeThreshold')
        pst_password = dictionary.get('pstPassword')

        # Return an object of this model
        return cls(create_pst,
                   encrypted_pst_password,
                   option_flags,
                   pst_name_prefix,
                   pst_password,
                   pst_size_threshold)
